@@ -1,6 +1,8 @@
 from .SeisLog import prep_data
 from .SeisLog import trace_extraction
+from .SeisLog import plot_extractions
+from .SeisLog import depth_conversion
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __author__ = 'Samara Omar'
 __credits__ = ''
